@@ -2,9 +2,9 @@
 Lightweight Python Build Tool
 """
 
-__authors__ = ['Raghunandan Rao', "Calum J. Eadie"]
+__version__ = "0.7.1"
 __license__ = "MIT License"
-__contact__ = "https://github.com/rags/pynt"
+__contact__ = "http://rags.github.com/pynt/"
 from ._pynt import task, main
 
 __all__ = ["task",  "main"]
\ No newline at end of file
